@@ -72,18 +72,6 @@ static void 	   bookmark_monitor_notify_cb 		(GnomeVFSMonitorHandle    *handle,
 		            				 GnomeVFSMonitorEventType  event_type,
 		            				 gpointer                  user_data);
 
-
-static char *
-get_default_bookmark_name (const char *text_uri)
-{
-	char *title;
-
-	title = nautilus_compute_title_for_uri (text_uri);
-	title = eel_str_middle_truncate (title, MAX_BOOKMARK_LENGTH);	
-	return title;
-
-}
-
 static NautilusBookmark *
 new_bookmark_from_uri (const char *uri, const char *label)
 {
@@ -94,7 +82,7 @@ new_bookmark_from_uri (const char *uri, const char *label)
 
 	has_label = FALSE;
 	if (!label) { 
-		name = get_default_bookmark_name (uri);
+		name = nautilus_compute_title_for_uri (uri);
 	} else {
 		name = g_strdup (label);
 		has_label = TRUE;
@@ -123,7 +111,7 @@ new_bookmark_from_uri (const char *uri, const char *label)
 }
 
 static char *
-nautilus_bookmark_list_get_file_path ()
+nautilus_bookmark_list_get_file_path (void)
 {
 	char *file_path;
 	file_path = g_build_filename (g_get_home_dir (),
@@ -449,6 +437,7 @@ static void
 nautilus_bookmark_list_load_file (NautilusBookmarkList *bookmarks)
 {
 	char *filename, *contents;
+	GError **error = NULL;
 
 	filename = nautilus_bookmark_list_get_file_path ();
 
@@ -462,7 +451,6 @@ nautilus_bookmark_list_load_file (NautilusBookmarkList *bookmarks)
 	}
 
 	/* Read new list from file */
-	GError **error = NULL;
 	if (g_file_get_contents (filename, &contents, NULL, error)) {
         	char **lines;
       		int i;
